# frozen_string_literal: true

require 'simplecov'

SimpleCov.start do
  add_filter %w[spec/ .github/]
end

require 'faraday'

require_relative '../lib/faraday/gzip'

Dir[File.join(__dir__, 'support/**/*.rb')].each { |f| require f }

RSpec.configure do |config|
  # Enable flags like --only-failures and --next-failure
  config.example_status_persistence_file_path = '.rspec_status'

  # Disable RSpec exposing methods globally on `Module` and `main`
  config.disable_monkey_patching!

  config.expect_with :rspec do |c|
    c.syntax = :expect
  end

  config.order = :random
  Kernel.srand config.seed

  config.include FaradayGzipSpecHelpers
end
